#include <iostream>
#include <string>
#include <vector>
#include <fstream>
#include <sstream>
#include <stdlib.h>

using namespace std;

void halt_pe () {
  cerr << "Presentation error" << endl;
  cout << "0" << endl;
  exit(0);
}

void halt_ok () {
  cerr << "OK" << endl;
  cout << "1" << endl;
  exit(0);
}

void halt_wa () {
  cerr << "Wrong answer" << endl;
  cout << "0" << endl;
  exit(0);
}

vector<long> line_to_vec (string line) {
  istringstream sin (line);

  vector<long> ans;
  string token;
  while (sin >> token) {
    char *p;
    long num = strtol(token.c_str(), &p, 10);
    if (*p) {
      halt_pe();
    } else {
      ans.push_back(num);
    }
  }

  return ans;
}

const int MAX_N = 3e5 + 5;

int root [MAX_N];
int find (int u) {
  if (root[u] != u) {
    root[u] = find(root[u]);
  }
  return root[u];
}

void merge (int u, int v) {
  u = find(u);
  v = find(v);

  root[u] = v;
}

int main (int argc, char **argv) {
  ifstream input_file (argv[1]);
  ifstream answer_file (argv[2]);
  ifstream student_file (argv[3]);

  int n, k;
  input_file >> n >> k;

  for (int i = 0; i < n; i++) {
    root[i] = i;
  }

  vector<pair<int, int>> edges;
  for (int i = 0; i < n - 1; i++) {
    int u, v;
    input_file >> u >> v;
    u--; v--;
    edges.push_back(make_pair(u, v));
  }
  input_file.close();

  string answer_verdict;
  getline(answer_file, answer_verdict);
  while (isspace(answer_verdict.back())) {
    answer_verdict.pop_back();
  }
  answer_file.close();
  
  string student_verdict;
  getline(student_file, student_verdict);
  while (isspace(student_verdict.back())) {
    student_verdict.pop_back();
  }

  if (student_verdict != answer_verdict) {
    halt_wa();
  }

  if (student_verdict == string("EI SAA")) {
    halt_ok();
  }

  string student_groups_line;
  getline(student_file, student_groups_line);

  string token;
  if (student_file >> token) {
    halt_pe();
  }
  
  vector<long> student_groups = line_to_vec(student_groups_line);
  if ((int) student_groups.size() != n) {
    halt_pe();
  }

  for (int i = 0; i < n; i++) {
    if (student_groups[i] < 1 || k < student_groups[i]) {
      halt_pe();
    }
    student_groups[i]--;
  }

  vector<int> cnt (k, 0);
  vector<int> fst (k, 0);
  for (int i = 0; i < n; i++) {
    cnt[student_groups[i]]++;
    fst[student_groups[i]] = i;
  }

  for (int i = 0; i < k; i++) {
    if (cnt[i] != cnt[0]) {
      halt_wa();
    }
  }

  for (auto pr : edges) {
    if (student_groups[pr.first] == student_groups[pr.second]) {
      merge(pr.first, pr.second);
    }
  }

  for (int i = 0; i < n; i++) {
    if (find(i) != find(fst[student_groups[i]])) {
      halt_wa();
    }
  }

  halt_ok();
}
