#include <iostream>
#include <vector>
#include <fstream>

using namespace std;

const int MAX_C = 1 << 16;
const int BLOCK = 1 << 8;
const int BLOCKC = (MAX_C + BLOCK - 1) / BLOCK;
const int INF = 1 << 30;

struct Point {
  int x, y, id;
};

int dist (Point p, Point q) {
  return abs(p.x - q.x) + abs(p.y - q.y);
}

vector<Point> bucket [BLOCKC][BLOCKC];

bool block_empty (int r, int c) {
  if (r < 0) return true;
  if (c < 0) return true;
  if (r >= BLOCKC) return true;
  if (c >= BLOCKC) return true;
  return bucket[r][c].empty();
}

pair<int, int> closest_in_bucket (int r, int c, Point q) {
  pair<int, int> ans = {INF, INF};
  for (auto p : bucket[r][c]) {
    ans = min(ans, {dist(p, q), p.id});
  }
  return ans;
}

int solve (Point q) {
  int r = q.x / BLOCK;
  int c = q.y / BLOCK;

  int bkat = INF;
  pair<int, int> ans = {INF, INF};
  for (int k = 0; k <= bkat; k++) {
    for (int i = 0; i <= k; i++) {
      if (!block_empty(r - k + i, c + i)) {
        bkat = min(bkat, 2 * (k + 2));
        ans = min(ans, closest_in_bucket(r - k + i, c + i, q));
      }

      if (!block_empty(r + i,     c - k + i)) {
        bkat = min(bkat, 2 * (k + 2));
        ans = min(ans, closest_in_bucket(r + i,     c - k + i, q));
      }

      if (!block_empty(r + k - i, c + i)) {
        bkat = min(bkat, 2 * (k + 2));
        ans = min(ans, closest_in_bucket(r + k - i, c + i, q));
      }

      if (!block_empty(r - i,     c - k + i)) {
        bkat = min(bkat, 2 * (k + 2));
        ans = min(ans, closest_in_bucket(r - i,     c - k + i, q));
      }
    }
  }
  return ans.second;
}

int main () {
  ios::sync_with_stdio(false);

  ifstream fin ("varvsis.txt");

  int N, Q;
  fin >> N >> Q;

  for (int i = 0; i < N; i++) {
    int z;
    Point p;
    fin >> p.x >> p.y >> z;
    p.id = i;

    bucket[p.x / BLOCK][p.y / BLOCK].push_back(p);
  }

  ofstream fout ("varvval.txt");
  for (int i = 0; i < Q; i++) {
    Point q;
    int z;
    fin >> q.x >> q.y >> z;

    fout << solve(q) << '\n';
  }
  fout.close();
}
