#include <iostream>
#include <vector>
#include <fstream>

using namespace std;

const int MAX_C = 1 << 16;
const int BLOCK = 850;
const int BLOCKC = (MAX_C + BLOCK - 1) / BLOCK;
const int INF = 1 << 30;

struct Point {
  int x, y, z, id;
};

int dist (Point p, Point q) {
  return abs(p.x - q.x) + abs(p.y - q.y) + abs(p.z - q.z);
}

vector<Point> bucket [BLOCKC][BLOCKC][BLOCKC];

bool block_empty (int r, int c, int l) {
  if (r < 0) return true;
  if (c < 0) return true;
  if (l < 0) return true;
  if (r >= BLOCKC) return true;
  if (c >= BLOCKC) return true;
  if (l >= BLOCKC) return true;
  return bucket[r][c][l].empty();
}

pair<int, int> closest_in_bucket (int r, int c, int l, Point q) {
  pair<int, int> ans = {INF, INF};
  for (auto p : bucket[r][c][l]) {
    ans = min(ans, {dist(p, q), p.id});
  }
  return ans;
}

int solve (Point q) {
  int r = q.x / BLOCK;
  int c = q.y / BLOCK;
  int l = q.z / BLOCK;

  int bmat = INF;
  pair<int, int> ans = {INF, INF};
  for (int m = 0; m <= bmat; m++) {
    for (int i = -m; i <= m; i++) {
      for (int j = -m; j <= m; j++) {
        if (!block_empty(r + i, c + j, l - m)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r + i, c + j, l - m, q));
        }

        if (!block_empty(r + i, c + j, l + m)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r + i, c + j, l + m, q));
        }

        if (!block_empty(r + i, c - m, l + j)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r + i, c - m, l + j, q));          
        }

        if (!block_empty(r + i, c + m, l + j)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r + i, c + m, l + j, q));          
        }

        if (!block_empty(r - m, c + i, l + j)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r - m, c + i, l + j, q));          
        }
        
        if (!block_empty(r + m, c + i, l + j)) {
          bmat = min(bmat, 2 * (m + 1));
          ans = min(ans, closest_in_bucket(r + m, c + i, l + j, q));          
        }
      }
    }
  }
  return ans.second;
}

int main () {
  ios::sync_with_stdio(false);

  ifstream fin ("varvsis.txt");

  int N, Q;
  fin >> N >> Q;

  for (int i = 0; i < N; i++) {
    Point p;
    fin >> p.x >> p.y >> p.z;
    p.id = i;

    bucket[p.x / BLOCK][p.y / BLOCK][p.z / BLOCK].push_back(p);
  }

  ofstream fout ("varvval.txt");
  for (int i = 0; i < Q; i++) {
    Point q;
    fin >> q.x >> q.y >> q.z;

    fout << solve(q) << '\n';
  }
  fout.close();
}
